;; Generated package description from xah-fly-keys.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "xah-fly-keys" "28.11.20260416140940.0.20260416.141130" "ergonomic modal keybinding minor mode." '((emacs "28.3")) :commit "30f1d28314424210f20bc09747cdcbed76b22d44" :maintainer '("Xah Lee" . "xah@xahlee.org") :keywords '("convenience" "vi" "vim" "ergoemacs" "keybinding") :url "http://xahlee.info/emacs/misc/xah-fly-keys.html")
